<h1 align="center"><br><a href="https://discord.gg/8R6YAmApdV"><img src="https://h.top4top.io/p_2088b2c5m1.jpg" width="600"></a><br></h1>

## More Info About Use -> [Pysc Overall Discord](https://discord.gg/8R6YAmApdV)

### What is this lib?
Python API to easily connect Amino servers

### How to install?
`pip install SAmino`
- **FOCUS!:** type `SAmino` **Not** `Amino`

### API Reference documentation
Soon...

- **Author**: ThePhoenix78
- **New Author**: SirLez
